# Deployment

As there is a great diversity of operating systems, hosting environments, and
[WSGI servers][Flask_production], it is hard to provide universal and useful
instructions for setting up KerkoApp for use in production.

The procedure will be similar to that of any [Flask] application, and there are
many guides on the web covering this topic for various environments.

That said, you may refer to the guide below for step-by-step instructions. Even
if your environment is different from the one this guide was designed for, it
might provide you with some useful hints.

[Deploying KerkoApp on Ubuntu 20.04 or 22.04 with nginx and
gunicorn](https://gist.github.com/davidlesieur/e1dafd09636a4bb333ad360e4b2c5d6d).

**TODO:docs: update guide & move it here**


[Flask]: https://pypi.org/project/Flask/
[Flask_production]: https://flask.palletsprojects.com/en/latest/deploying/
